@@ -111,7 +111,8 @@ class CustomImputer:
         if numeric_features_index:
             for feat in X.columns.copy().values:
                 if feat in X.columns[numeric_features_index].copy():
-                    X.loc[:, feat] = X[feat].copy().astype('float64')
+                    # X.loc[:, feat] = X[feat].copy().astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
 
         return X.fillna(self.fill_values)
 
