@@ -30,13 +30,14 @@ class OptunaSearch:
     '''OptunaSearch implements fit, predict (from the estimator) get_best_model, get_best_model_by_ks (for classification only)'''
     def __init__(self, task:str, models:str = ['all'], n_trials:int = 10, n_folds:int = 5,
     compute_ks:bool = False,
-    feature_selection:bool = False):
+    feature_selection:bool = False, multi_class = False):
         self.models = models
         self.n_trials = n_trials
         self.task = task
         self.compute_ks = compute_ks
         self.n_folds = n_folds
         self.feature_selection = feature_selection
+        self.multi_class = multi_class
         
 
         self.feature_selector_search_space = [{'max_depth': [5]}]
@@ -74,12 +75,22 @@ class OptunaSearch:
                     self.objectives['xgb'] =  OptunaObjectives.__objective_xgb_regressor__
             elif model == 'catboost':
                 if self.task == 'classification':
-                    self.objectives['catboost'] = OptunaObjectives.__objective_catboost_classifier__
+                    self.objectives['catboost'] = None
+                    if self.multi_class:
+                        self.objectives['catboost'] = OptunaObjectives.__objective_catboost_classifier_multi__
+                    else:
+                        self.objectives['catboost'] = OptunaObjectives.__objective_catboost_classifier__
+
                 elif self.task == 'regression':
                     self.objectives['catboost'] = OptunaObjectives.__objective_catboost_regressor__        
             elif model == 'lgbm':
                 if self.task == 'classification':
-                    self.objectives['lgbm'] = OptunaObjectives.__objective_lgbm_classifier__
+                    self.objectives['lgbm'] = None
+                    if self.multi_class:
+                        self.objectives['lgbm'] = OptunaObjectives.__objective_lgbm_classifier_multi__
+                    else:
+                        self.objectives['lgbm'] = OptunaObjectives.__objective_lgbm_classifier__
+
                 elif self.task == 'regression':
                     self.objectives['lgbm'] =  OptunaObjectives.__objective_lgbm_regressor__
             elif model == 'decision_tree':
@@ -177,9 +188,16 @@ class OptunaSearch:
                         pipe = self.get_pipe(model_name, self.task, params)
 
                     pipe.fit(X.iloc[train_idx,:], y.iloc[train_idx])
-                    pred = pipe.predict(X.iloc[test_idx,:])
+                    pred = None
 
-                    metric = roc_auc_score(y.iloc[test_idx], pred)
+                    metric = None
+                    if len(np.unique(y)) > 2:
+                        pred = pipe.predict_proba(X.iloc[test_idx,:])          
+                        metric = roc_auc_score(y.iloc[test_idx], pred,multi_class= 'ovo',   average='weighted')
+                    else:
+                        pred = pipe.predict(X.iloc[test_idx,:])          
+                        metric = roc_auc_score(y.iloc[test_idx], pred)
+          
                     models_per_objective.append((metric, pipe))     
                 best_models.append(self.__get_internal_best_model__(models_per_objective))
                 
@@ -214,7 +232,6 @@ class OptunaSearch:
                                                 ('estimator', Base.Estimator(XGBClassifier(**params)))])
                 elif model_name == 'catboost':
                     pipe = Pipeline(steps = [('imputer', CustomImputer()),
-                                            ("dummies", Base.GetDummiesTransformer()),
                                             ('fs', Base.FeatureSelector(fs_settings)),
                                             ('estimator', Base.Estimator(CatBoostClassifierScikit(params)))])                   
                 elif model_name == 'lgbm':
@@ -251,6 +268,7 @@ class OptunaSearch:
                                             ('estimator', Base.Estimator(CatBoostRegressorScikit(params)))])                   
                 elif model_name == 'lgbm':
                     pipe = Pipeline(steps = [('imputer', CustomImputer()),
+                                            ("dummies", Base.GetDummiesTransformer()),
                                             ('fs', Base.FeatureSelector(fs_settings)),
                                             ('estimator', Base.Estimator(LGBMRegressor(**params)))]) 
                 elif model_name == 'decision_tree':
@@ -265,6 +283,7 @@ class OptunaSearch:
                                             ('estimator', Base.Estimator(AdaBoostRegressor(**params)))])
                 elif model_name == 'svr':       
                     pipe = Pipeline(steps = [('imputer', CustomImputer()),
+                                            ("dummies", Base.GetDummiesTransformer()),
                                             ('fs', Base.FeatureSelector(fs_settings)),
                                             ('estimator', Base.Estimator(SVR(**params)))])    
                 else:
@@ -279,7 +298,6 @@ class OptunaSearch:
                                             ('estimator', Base.Estimator(XGBClassifier(**params)))])
             elif model_name == 'catboost':
                 pipe = Pipeline(steps = [('imputer', CustomImputer()),
-                                        ("dummies", Base.GetDummiesTransformer()),
                                         ('estimator', Base.Estimator(CatBoostClassifierScikit(params)))])                   
             elif model_name == 'lgbm':
                 pipe = Pipeline(steps = [('imputer',CustomImputer()),
@@ -306,7 +324,6 @@ class OptunaSearch:
                                             ('estimator', Base.Estimator(XGBRegressor(**params)))])
             elif model_name == 'catboost':
                 pipe = Pipeline(steps = [('imputer', CustomImputer()),
-                                        ("dummies", Base.GetDummiesTransformer()),
                                         ('estimator', Base.Estimator(CatBoostRegressorScikit(params)))])                   
             elif model_name == 'lgbm':
                 pipe = Pipeline(steps = [('imputer', CustomImputer()),
@@ -342,8 +359,17 @@ class OptunaSearch:
             roc_results = []
             for model in models:
                 model.fit(X, y)
-                y_pred = model.predict(X)
-                roc = roc_auc_score(y, y_pred)
+                y_pred = None
+                roc = None
+
+                if len(np.unique(y)) > 2:
+                    y_pred = model.predict_proba(X)
+                    roc = roc_auc_score(y, y_pred, multi_class='ovr', average='weighted')
+                else:
+                    y_pred = model.predict(X)
+                    roc = roc_auc_score(y, y_pred)
+
+
                 roc_results.append((roc, model))
             return self.__get_best_model_by_simple_metric__(roc_results)     
         elif task == 'regression':
