@@ -37,8 +37,8 @@ class OptunaObjectives:
             numeric_features = [col for col in X.columns if X[col].dtypes == 'int64' or X[col].dtypes == 'float64' 
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
-                for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                for feat in numeric_features.copy():
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -75,7 +75,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -108,7 +108,7 @@ class OptunaObjectives:
             if numeric_features:
                 for feat in numeric_features:
                     # X.loc[:,X.columns == feat] =X.loc[:,X.columns == feat].astype('float64')
-                    X.loc[:,feat] =X[feat].apply(lambda x: np.float(x )).copy()
+                    X.loc[:][feat] = X[feat].astype('float64')
 
         except:
             pass
@@ -150,7 +150,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] =X.loc[:,X.columns == feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -187,7 +187,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -231,7 +231,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -270,7 +270,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -311,7 +311,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -333,7 +333,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -364,7 +364,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -387,7 +387,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -417,7 +417,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -436,7 +436,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[feat].astype('float64')
         except:
             pass
 
@@ -467,7 +467,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:,X.columns == feat] = X[feat].astype('float64')
+                    X.loc[:, feat] = X[feat].copy().astype('float64')
         except:
             pass
 
